package My::Schema::Result::Tweet;
use strict;
use warnings;
use base 'DBIx::Class::Core';

use DateTime;

__PACKAGE__->load_components(qw/InflateColumn::DateTime/);

__PACKAGE__->table('tweet');
__PACKAGE__->add_columns(
    id => {
        data_type         => 'INTEGER',
        is_nullable       => 0,
        is_auto_increment => 1,
    },

    user => {
        data_type   => 'INTEGER',
        is_nullable => 0,
    },

    body => {
        data_type   => 'VARCHAR',
        is_nullable => 0,
    },

    created_date => {
        data_type   => 'DATETIME',
        is_nullable => 0,
        timezone    => 'Asia/Tokyo',
    },

    modified_date => {
        data_type   => 'DATETIME',
        is_nullable => 0,
        timezone    => 'Asia/Tokyo',
    },
);
__PACKAGE__->set_primary_key('id');

__PACKAGE__->belongs_to( user => 'My::Schema::Result::User' );

# *_date カラムを自動更新にする
sub insert {
    my $self = shift;

    my $now = DateTime->now;
    $self->created_date($now);
    $self->modified_date($now);

    $self->next::method(@_);
}

sub update {
    my $self = shift;

    $self->modified_date(DateTime->now);
    $self->next::method(@_);
}

1;
